Campaign class

Annotations
  • @JsonSerializable.new()

Constructors

Campaign({required String id, String? screen, Map<String, dynamic>? content, List? variants, Map<String, dynamic>? metadata, Map<String, dynamic>? details})
Campaign.fromJson(Map<String, dynamic> json)
factory

Properties

content Map<String, dynamic>?
final
details Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
metadata Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen String?
final
variants List?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited