ScreenCampaignResult class
Constructors
Properties
-
campaigns
→ List<
Map< ?String, dynamic> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
personalizationData
→ Map<
String, dynamic> -
final
-
resolvedVariants
→ List<
Map< String, dynamic> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenCaptureEnabled → bool
-
final
- testUser → bool
-
final
-
variants
→ List<
CampaignVariant> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited